from typing import Optional

from pydantic import Extra
from pydantic_settings import BaseSettings, SettingsConfigDict


class Settings(BaseSettings):
    debug: bool = False
    version: str = 'beta'
    version_name: str = 'Unklar'

    loaded_modules: list[str] = []
    js_modules: list[str] = []

    oic_client_id: str = ""
    oic_client_secret: str = ''
    oic_endpoint: str = 'https://oidc.scc.kit.edu/auth/realms/kit'
    # TODO: rename to base url
    oic_redirect_host: str = ''
    oic_redirect_path: str = '/oic_login'

    require_2fa: bool = True

    jwt_secret: str = ''
    jwt_algorithm: str = 'HS256'

    minidhcpvs_host: str = 'net-pgsql-dhcp-1.scc.kit.edu'
    minidhcpvs_port: int = 5432
    minidhcpvs_db: str = 'mac_addrs'
    minidhcpvs_user: str = ''
    minidhcpvs_password: str = ''

    oui_lookup_disabled: bool = False

    redis_url: str = ''

    macfinder_redis_db_index: int = 1
    macfinder_server_url: str = ''
    macfinder_cert: str = ''
    macfinder_key: str = ''
    macfinder_ca: str = ''

    aplist_server_url: str = ''
    aplist_cert: str = ''
    aplist_key: str = ''
    aplist_ca: str = ''

    patch_request_email_receivers: Optional[str] = None
    patch_request_email_sender: str = ''
    patch_request_assignment: dict[str, str] = {}

    bcd_request_email_receivers: str = None
    bcd_request_override_mail_receiver: Optional[str] = None
    bcd_request_email_sender: str = ''

    mail_smarthost: str = 'smarthost.kit.edu'

    ip_contact_send_mail: bool = True
    ip_contact_override_mail_receiver: Optional[str] = None
    ip_contact_email_sender: str = ''

    netdb_admin_base: str = 'https://admin.netdb.scc.kit.edu'

    wapi_netvs_superuser: str = ''

    null_login_name: Optional[str] = None

    # Load settings from .env
    model_config = SettingsConfigDict(env_file=".env", extra=Extra.allow)


settings = Settings()
